'use strict';

function camel2Underline(_str) {
	var str = _str[0].toLowerCase() + _str.substr(1);

	return str.replace(/([A-Z])/g, function ($1) {
		return '_' + $1.toLowerCase();
	});
}

function camel2Dash(_str) {
	var str = _str[0].toLowerCase() + _str.substr(1);
	return str.replace(/([A-Z])/g, function ($1) {
		return '-' + $1.toLowerCase();
	});
}

module.exports = function core() {
	return function (_ref) {
		var types = _ref.types;
		return {
			visitor: {
				ImportDeclaration: function ImportDeclaration(path, _ref2) {
					var opts = _ref2.opts;

					var specifiers = path.node.specifiers;
					var source = path.node.source;

					if (Array.isArray(opts) && !opts.find(function (opt) {
						return opt.libraryName === source.value;
					})) return;
					if (!Array.isArray(opts) && opts.libraryName !== source.value) return;

					var opt = Array.isArray(opts) ? opts.find(function (opt) {
						return opt.libraryName === source.value;
					}) : opts;
					opt.camel2UnderlineComponentName = typeof opt.camel2UnderlineComponentName === 'undefined' ? false : opt.camel2UnderlineComponentName;
					opt.camel2DashComponentName = typeof opt.camel2DashComponentName === 'undefined' ? false : opt.camel2DashComponentName;

					if (!types.isImportDefaultSpecifier(specifiers[0]) && !types.isImportNamespaceSpecifier(specifiers[0])) {
						var declarations = specifiers.map(function (specifier) {
							var transformedSourceName = opt.camel2UnderlineComponentName ? camel2Underline(specifier.imported.name) : opt.camel2DashComponentName ? camel2Dash(specifier.imported.name) : specifier.imported.name;
							return types.ImportDeclaration([types.ImportDefaultSpecifier(specifier.local)], types.StringLiteral(opt.customSourceFunc(transformedSourceName)));
						});
						path.replaceWithMultiple(declarations);
					}
				}
			}
		};
	};
};